#!/bin/sh
#
# code by ngc1927

rm -f /var/bin/scrplg-ushare-start.sh
rm -f /var/bin/scrplg-ushare-stop.sh
rm -f /var/bin/ushare

rm -rf /var/doc/cuberevo-ushare

rm -f /var/etc/ushare.conf

rm -f /var/uninstall/cuberevo-ushare-1.1a_delfile.sh

exit 0
